simple <- read.csv("simple.txt")
simple$class <- as.factor(simple$class)

plot(simple$x1,simple$x2,col=simple$class)

ind <- sample(1:0.6*nrow(simple),0.6*nrow(simple))

train <- simple[ind,]
test <- simple[-ind,]

# Jednoduchý decision stump klasifikátor
library(rpart)
library(rpart.plot)
stump <- rpart(class ~ .,data = train,control = rpart.control(maxdepth=1,cp=-1))
prp(stump, type=2, extra=101, nn=TRUE, fallen.leaves=TRUE,
    faclen=0, varlen=0, shadow.col="grey", branch.lty=3)
stumpError <- sum(predict(stump,newdata=test,type='class') != test$class)/nrow(test)
stumpConfusion <- table(predict(stump,newdata=test,type='class'),test$class)

print(stumpConfusion)
plot(test$x1,test$x2,col=predict(stump,newdata=test,type='class'))


library(adabag)
library(rpart)

# Porota složená z klasifikátorů - bagging
baggedStumps <- bagging(class ~ .,data=train,mfinal=20,control=rpart.control(maxdepth=1,cp=-1))
baggedStumps.perf <- predict.bagging(baggedStumps,newdata=test)

plot(train$x1,train$x2,col=as.factor(predict(baggedStumps,newdata=train)$class),xlab='x1',ylab='x2',pch=20)
plot(test$x1,test$x2,col=as.factor(predict(baggedStumps,newdata=test)$class),xlab='x1',ylab='x2',pch=20)

# Porota složená z klasifikátorů - AdaBoost
boostedStumps <- boosting(class ~ .,data=train,mfinal=30,boos=T,control=rpart.control(maxdepth=1,cp=-1))
boostedStumps.perf <- predict.boosting(boostedStumps,newdata=test)

plot(train$x1,train$x2,col=as.factor(predict(boostedStumps,newdata=train)$class),xlab='x1',ylab='x2',pch=20)
plot(test$x1,test$x2,col=as.factor(predict(boostedStumps,newdata=test)$class),xlab='x1',ylab='x2',pch=20)


# Human Activity Recognition
library(randomForest)
library(adabag)
library(rpart)

load("train.RData")
load("test.RData")

tree <- rpart(activity ~ .,data = train)

forest1 <- bagging(activity ~ .,data = train,mfinal=20)
forest1.pred <- predict.bagging(forest1,newdata=test)
print(forest1.pred$error)
print(forest1.pred$confusion)

forest2 <- randomForest(activity ~ .,data = train,ntree=20)
forest2$error <- sum(predict(forest2,newdata = test,type='response') != test$activity)/nrow(test)
forest2$confusion <- table(predict(forest2,newdata = test,type='response'),test$activity)
print(forest2$error)
print(forest2$confusion)

forest3 <- boosting(activity ~ .,data = train,mfinal=20,boos=T,coeflearn='Zhu')
forest3.pred <- predict.boosting(forest3,newdata=test)
print(forest3.pred$error)
print(forest3.pred$confusion)

